"""
Imports for generated models and context classes.
"""
# Standard library imports
import uuid
import importlib
from typing import Any, Dict, List, Optional, Type, TypeVar, Union, cast, TypedDict, Generic, Callable
from dataclasses import dataclass, field

# Django and Pydantic imports
from django.db import models
from pydantic import BaseModel

# Pydantic2Django imports
from pydantic2django.django.models import Pydantic2DjangoBaseClass, Pydantic2DjangoStorePydanticObject, Dataclass2DjangoBaseClass
from pydantic2django.core.context import ModelContext, FieldContext

# Additional type imports from typing module
{% if typing_imports %}
from typing import {{ typing_imports|join(', ') }}
{% endif %}

# Original Pydantic model imports
{% for import_line in pydantic_imports %}
{{ import_line }}
{% endfor %}

# Context class field type imports
{% for import_line in context_imports %}
{{ import_line }}
{% endfor %}

# Type variable for model classes
T = TypeVar('T')
